'use strict';

/* eslint no-underscore-dangle: off */
var eventListeners = {};

if (!global._nocmsEventListeners) {
  global._nocmsEventListeners = {};
}

var _trigger = function _trigger(eventName, eventStore) {
  for (var _len = arguments.length, args = Array(_len > 2 ? _len - 2 : 0), _key = 2; _key < _len; _key++) {
    args[_key - 2] = arguments[_key];
  }

  if (!eventStore[eventName]) {
    return;
  }
  var subscribers = eventStore[eventName].slice();
  subscribers.forEach(function (f) {
    f.apply(undefined, args);
  });
};

var _listenTo = function _listenTo(eventName, func, eventStore) {
  if (typeof func !== 'function') {
    /* eslint no-console: off */
    /* eslint no-param-reassign: off  */
    console.error('Listener to ' + eventName + '  is not a function');
    return;
  }
  if (!eventStore[eventName]) {
    eventStore[eventName] = [];
  }
  eventStore[eventName].push(func);
};

var _stopListenTo = function _stopListenTo(eventName, func, eventStore) {
  if (!eventStore[eventName]) {
    return;
  }
  var index = eventStore[eventName].indexOf(func);
  if (index !== -1) {
    eventStore[eventName].splice(index, 1);
  }
};

var _clearEvent = function _clearEvent(eventName) {
  var eventStore = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : eventListeners;

  delete eventStore[eventName];
};

var trigger = function trigger(eventName) {
  for (var _len2 = arguments.length, args = Array(_len2 > 1 ? _len2 - 1 : 0), _key2 = 1; _key2 < _len2; _key2++) {
    args[_key2 - 1] = arguments[_key2];
  }

  _trigger.apply(undefined, [eventName, eventListeners].concat(args));
};

var listenTo = function listenTo(eventName, func) {
  _listenTo(eventName, func, eventListeners);
};

var stopListenTo = function stopListenTo(eventName, func) {
  _stopListenTo(eventName, func, eventListeners);
};

var clearEvent = function clearEvent(eventName) {
  _clearEvent(eventName, eventListeners);
};

var triggerGlobal = function triggerGlobal(eventName) {
  for (var _len3 = arguments.length, args = Array(_len3 > 1 ? _len3 - 1 : 0), _key3 = 1; _key3 < _len3; _key3++) {
    args[_key3 - 1] = arguments[_key3];
  }

  _trigger.apply(undefined, [eventName, global._nocmsEventListeners].concat(args));
};

var listenToGlobal = function listenToGlobal(eventName, func) {
  _listenTo(eventName, func, global._nocmsEventListeners);
};

var stopListenToGlobal = function stopListenToGlobal(eventName, func) {
  _stopListenTo(eventName, func, global._nocmsEventListeners);
};

var clearEventGlobal = function clearEventGlobal(eventName) {
  _clearEvent(eventName, global._nocmsEventListeners);
};

module.exports = {
  listenTo: listenTo,
  listenToGlobal: listenToGlobal,
  stopListenTo: stopListenTo,
  stopListenToGlobal: stopListenToGlobal,
  trigger: trigger,
  triggerGlobal: triggerGlobal,
  clearEvent: clearEvent,
  clearEventGlobal: clearEventGlobal
};
//# sourceMappingURL=index.js.map